\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{aciids}%[2022/10/2 ACIIDS abstract class]

\newcommand{\headlinecolor}{\normalcolor}
\RequirePackage{xcolor}
\definecolor{slcolor}{HTML}{882B21}

\RequirePackage{times}
\RequirePackage{url}
\RequirePackage{mathptmx}

\DeclareOption{onecolumn}{\OptionNotUsed}
\DeclareOption{green}{\renewcommand{\headlinecolor}{\color{green}}}
\DeclareOption{red}{\renewcommand{\headlinecolor}{\color{slcolor}}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass{article}

\renewcommand{\thesection}{\Roman{section}}

\RequirePackage[a4paper,top=2.5cm,left=2.5cm,right=2.5cm,bottom=2.5cm]{geometry}
\RequirePackage{titlesec}
\RequirePackage{fancyhdr}

%%%% Footer
\pagestyle{fancy}
\fancyhf{}
\renewcommand{\headrulewidth}{0pt}
\lfoot{\scriptsize Reproduced with permission from Springer Nature}
\rfoot{\scriptsize\thepage}

%%%% Formatting
\titleformat{\section}{\normalfont\normalsize\bfseries\scshape}{\thesection}{1em}{}%
\titleformat{\subsection}{\normalfont\normalsize\itshape}{\thesubsection}{1em}{}%
\titleformat{\subsubsection}{\normalfont\normalsize\itshape}{\thesubsubsection}{1em}{}%

%%%%%%%% Spacing
\titlespacing*{\section}{0pt}{*1.2}{*1.2}
\titlespacing*{\subsection}{0pt}{*1.2}{*1.2}
\titlespacing*{\subsubsection}{0pt}{*1.2}{*1.2}

\newcommand{\orcid}[1]{\textsuperscript{[#1]}}

\def\email#1{\gdef\@email{\small\url{#1}}}
\def\@email{\@latex@error{No \noexpand\email given}\@ehc}

\def\keywords#1{\gdef\@keywords{#1}}
\def\@keywords{\@latex@error{No \noexpand\keywords given}\@ehc}


\def\arXiv#1{\gdef\@arXiv{\small\url{#1}}}
\def\@arXiv{No arXiv link given.}

\def\DOI#1{\gdef\@DOI{\small\url{#1}}}
\def\@DOI{\@latex@error{No \noexpand\DOI given}\@ehc}

\def\repository#1{\gdef\@repository{\small\url{#1}}}
\def\@repository{No repository given.}

\def\affiliation#1{\gdef\@affiliation{{#1}}}
\def\@affiliation{No affiliation given.}

\def\affilno#1{\textsuperscript{#1}}

% sections required
\def\abstract#1{\gdef\@abstract{\section*{Abstract}#1}}%
\def\@abstract{No abstract given.}

\def\simpletitle#1{\gdef\@simpletitle{\section*{Simplified Title}#1}}%
\def\@simpletitle{No simplified title given.}

\renewcommand{\maketitle}{%
        %\fontseries{b}%
         {\small%
        \noindent\textbf{Link to arXiv: }{\@arXiv}\\%
        \textbf{DOI: }{\@DOI}\\%
        \textbf{Link to repository: }{\@repository}\medskip\\%
        \textbf{Keywords: }{\@keywords}\\%        
        \hrule
        }
        \begin{center}%
            \textbf{\LARGE\@title}%\medskip\newline%
        \end{center}%
        \begin{center}%
            {\normalsize \@author\smallskip\\{\@affiliation}}%    
        \end{center}
        \begin{center}%
            {\large \@email}%    
        \end{center}\smallskip%
        \@simpletitle
        \@abstract
        \bigskip\hrule
%      \hrule%                    
}

\def\SimpleTitle{\section*{Simplified Title}}%
\def\Introduction{\section{Introduction}}%
\def\StateOfTheArt{\section{State of the Art}}%
\def\OriginalContribution{\section{Original Contribution}}%
\def\Methodology{\section{Methodology}}%
\def\Results{\section{Results}}%
\def\Evaluation{\section{Evaluation}}%
\def\Conclusions{\section{Conclusions}}%




